summaryrefslogtreecommitdiffstats
path: root/test
diff options
context:
space:
mode:
Diffstat (limited to 'test')
-rw-r--r--test/functional/application_controller_test.rb5
1 files changed, 3 insertions, 2 deletions
diff --git a/test/functional/application_controller_test.rb b/test/functional/application_controller_test.rb
index 3dbeadb97..3a40b15a9 100644
--- a/test/functional/application_controller_test.rb
+++ b/test/functional/application_controller_test.rb
@@ -28,9 +28,10 @@ class ApplicationControllerTest < Test::Unit::TestCase
@response = ActionController::TestResponse.new
end
# check that all 6 supported languages are valid
def test_localization
- assert_equal 10, GLoc.valid_languages.size
+ lang_files_count = Dir["#{RAILS_ROOT}/lang/*.yml"].size
+ assert_equal lang_files_count, GLoc.valid_languages.size
GLoc.valid_languages.each do |lang|
assert set_language_if_valid(lang)
end
@@ -28,9 +28,10 @@ class ApplicationControllerTest < Test::Unit::TestCase
end
- # check that all 6 supported languages are valid
+ # check that all language files are valid
def test_localization